### Name: geom_bar
### Title: geom_bar
### Aliases: geom_bar GeomBar
### Keywords: hplot

### ** Examples
## Not run: 
##D # Generate data
##D c <- ggplot(mtcars, aes(x=factor(cyl)))
##D 
##D c + geom_bar()
##D c + geom_bar() + coord_flip()
##D c + geom_bar(fill="white", colour="darkgreen")
##D 
##D # Use qplot
##D qplot(factor(cyl), data=mtcars, geom="bar")
##D qplot(factor(cyl), data=mtcars, geom="bar", fill=factor(cyl))
##D 
##D # Stacked bar charts    
##D qplot(factor(cyl), data=mtcars, geom="bar", fill=factor(vs))
##D qplot(factor(cyl), data=mtcars, geom="bar", fill=factor(gear))
##D 
##D ggplot(diamonds, aes(x=price, fill=cut)) + geom_bar()
##D ggplot(diamonds, aes(x=clarity, fill=cut)) + geom_bar()
##D ggplot(diamonds, aes(x=price, fill=cut)) + geom_bar() + coord_flip()
##D 
##D # Dodged bar charts    
##D ggplot(diamonds, aes(x=clarity, fill=cut)) + geom_bar(position="dodge")
##D # compare with 
##D ggplot(diamonds, aes(x=cut, fill=cut)) + geom_bar() + facet_grid(. ~ clarity)
##D 
##D # But may be better to use a line plot instead:
##D ggplot(diamonds, aes(x=clarity, colour=cut)) + 
##D   geom_line(aes(group = cut, y = ..count..), stat="bin")
##D 
##D # Often we don't want the height of the bar to represent the
##D # count of observations, but the sum of some other variable.
##D # For example, the following plot shows the number of movies
##D # in each rating.
##D qplot(rating, data=movies, geom="bar")
##D # If, however, we want to see the number of votes cast in each
##D # category, we need to weight by the votes variable
##D qplot(rating, data=movies, geom="bar", weight=votes)
##D # We could also see the total expenditure for each category:
##D qplot(rating, data=movies, geom="bar", weight=budget)
##D 
##D # A bar chart used to display means
##D meanprice <- tapply(diamonds$price, diamonds$cut, mean)
##D cut <- factor(levels(diamonds$cut), levels = levels(diamonds$cut))
##D qplot(cut, meanprice)
##D qplot(cut, meanprice, geom="bar", stat="identity")
## End(Not run)


